package main

import (
	"os"
	"os/user"
	"path/filepath"

	"go.wit.com/log"

	"go.wit.com/gui"
	"go.wit.com/lib/gadgets"
	"go.wit.com/lib/gui/repolist"
	"go.wit.com/lib/gui/repostatus"
)

func doesExist(path string) bool {
	if _, err := os.Stat(path); err != nil {
		if os.IsNotExist(err) {
			return false
		}
	}
	return true
}

// only errors on bad errors
func quickCmd(fullpath string, cmd []string) bool {
	var err error
	var b bool
	var output string

	//	if me.autoWorkingPwd.String() != fullpath {
	//		me.autoWorkingPwd.SetValue(fullpath)
	//	}

	if me.autoDryRun.Checked() {
		log.Warn("RUN --dry-run", fullpath, cmd)
		return false
	} else {
		log.Warn("RUN:", fullpath, cmd)
	}

	err, b, output = repostatus.RunCmd(fullpath, cmd)
	if err != nil {
		log.Warn("cmd =", cmd)
		log.Warn("err =", err)
		log.Warn("b =", b)
		log.Warn("output =", string(output))
		return false
	} else if !b {
		log.Warn("b =", b)
		log.Warn("output =", string(output))
		return true
	}
	log.Warn("output = ", string(output))
	return true
}

func globalBuildOptions(vbox *gui.Node) {
	group1 := vbox.NewGroup("Global Build Options")
	grid := group1.NewGrid("buildOptions", 0, 0)

	// me.autoWorkingPwd = gadgets.NewOneLiner(grid, "working directory (pwd)")
	me.userHomePwd = gadgets.NewOneLiner(grid, "user home")
	grid.NextRow()
	me.goSrcPwd = gadgets.NewOneLiner(grid, "go src home")
	grid.NextRow()

	usr, _ := user.Current()
	homeDir, err := os.UserHomeDir()
	if err != nil {
		log.Warn("Error getting home directory:", err)
		homeDir = "/home/autotypist"
	}
	me.userHomePwd.SetText(homeDir)
	srcDir := filepath.Join(homeDir, "go/src")
	me.goSrcPwd.SetText(srcDir)

	// select the branch you want to test, build and develop against
	// this lets you select your user branch, but, when you are happy
	// you can merge everything into the devel branch and make sure it actually
	// works. Then, when that is good, merge and version everything in master
	me.setBranchB = grid.NewButton("set current branch to:", func() {
		targetName := me.newBranch.String()
		log.Warn("setting all branches to", targetName)
		for _, repo := range repolist.AllRepos() {
			repo.Status.CheckoutBranch(targetName)
			repo.Scan()
		}
	})
	me.newBranch = grid.NewCombobox()
	me.newBranch.AddText("master")
	me.newBranch.AddText("devel")
	me.newBranch.AddText(usr.Username)
	me.newBranch.SetText(usr.Username)

	// checking this will automatically make the branches off of devel
	me.autoCreateBranches = grid.NewCheckbox("create if missing").SetChecked(true)
	grid.NextRow()
}

// this code isn't ready yet
/*
	s.gitPullB = grid.NewButton("git pull", func() {
		me.Disable()
		defer me.Enable()
		for _, repo := range repolist.AllRepos() {
			// gitcmd := []string{"git", "fetch", "origin"}
			gitcmd := []string{"git", "pull"}
			err, output := repo.RunCmd(gitcmd)
			log.Info("output =", output)
			if err == nil {
				log.Info("git fetch worked", repo.Name())
			} else {
				log.Info("git fetch failed", repo.Name())
				return
			}
		}
		gitPullB.SetText("GOOD")
		// update the stats
		// s.Update()
	})

	s.gitPushB = grid.NewButton("git push", func() {
		me.Disable()
		defer me.Enable()
		for _, repo := range repolist.AllRepos() {
			gitcmd := []string{"git", "push"}
			err, output := repo.RunCmd(gitcmd)
			log.Info("output =", output)
			if err == nil {
				log.Info("git push worked", repo.Name())
			} else {
				log.Info("git push failed", repo.Name())
				return
			}
		}
		s.gitPushB.SetText("GOOD")
		// update the stats
		s.Update()
	})

	s.checkB = s.grid.NewButton("Check repos are working", func() {
			me.Disable()
			defer me.Enable()
			for _, repo := range repolist.AllRepos() {
				if repo.GitURL() != "" {
					log.Info("repo already checked. do they match?")
					log.Info("go.wit.com =", repo.GoURL())
					log.Info("localurl   =", repo.Path())
				} else {
					ok, giturl := gowit.CheckRegistered(repo)
					if ok {
						log.Info("is url correct?", repo.Path(), "vs", giturl)
						repo.giturl = giturl
						if giturl != repo.Path() {
							log.Info("repo check failed", repo.String())
							s.unknownOL.SetText(repo.String())
							s.unknownOL.Show()
							s.unknownSubmitB.Show()
							return
						}
					} else {
						log.Info("repo check failed", repo.String())
						repo.giturl = "look in .git/config"
						s.unknownOL.SetText(repo.String())
						s.unknownOL.Show()
						s.unknownSubmitB.Show()
						return
					}
				}
			}
			s.checkB.SetText("GOOD")
	})
*/
